@@ -1,29 +1,27 @@
 /*
- * This file is part of the KDE project, module kdesu.
- * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
- *
- * This is free software; you can use this library under the GNU Library
- * General Public License, version 2. See the file "COPYING.LIB" for the
- * exact licensing terms.
- *
- * client.cpp: A client for kdesud.
- */
+    This file is part of the KDE project, module kdesu.
+    SPDX-FileCopyrightText: 1999, 2000 Geert Jansen <jansen@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-only
+
+    client.cpp: A client for kdesud.
+*/
 
 #include "client.h"
 
+#include <ksu_debug.h>
 #include <config-kdesu.h>
 
 #include <errno.h>
 #include <sys/socket.h>
 #include <sys/un.h>
 
-#include <QtCore/QFile>
-#include <QtCore/QRegExp>
+#include <QFile>
+#include <QRegularExpression>
 #include <QStandardPaths>
 #include <qplatformdefs.h>
-#include <QDebug>
 
-#include <ktoolinvocation.h>
+#include <KToolInvocation>
 
 extern int kdesuDebugArea();
 
@@ -54,12 +52,12 @@ KDEsuClient::KDEsuClient()
         display = QString::fromLocal8Bit(qgetenv("WAYLAND_DISPLAY"));
     }
     if (display.isEmpty()) {
-        qWarning() << "[" << __FILE__ << ":" << __LINE__ << "] " << "$DISPLAY is not set.";
+        qCWarning(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] " << "$DISPLAY is not set.";
         return;
     }
 
     // strip the screen number from the display
-    display.remove(QRegExp(QStringLiteral("\\.[0-9]+$")));
+    display.remove(QRegularExpression(QStringLiteral("\\.[0-9]+$")));
 #else
     QString display = QStringLiteral("NODISPLAY");
 #endif
@@ -90,7 +88,7 @@ int KDEsuClient::connect()
 
     d->sockfd = socket(PF_UNIX, SOCK_STREAM, 0);
     if (d->sockfd < 0) {
-        qWarning() << "[" << __FILE__ << ":" << __LINE__ << "] " << "socket():" << strerror(errno);
+        qCWarning(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] " << "socket():" << strerror(errno);
         return -1;
     }
     struct sockaddr_un addr;
@@ -98,7 +96,7 @@ int KDEsuClient::connect()
     strcpy(addr.sun_path, d->sock.constData());
 
     if (QT_SOCKET_CONNECT(d->sockfd, (struct sockaddr *) &addr, SUN_LEN(&addr)) < 0) {
-        qWarning() << "[" << __FILE__ << ":" << __LINE__ << "] " << "connect():" << strerror(errno);
+        qCWarning(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] " << "connect():" << strerror(errno);
         close(d->sockfd); d->sockfd = -1;
         return -1;
     }
@@ -109,7 +107,7 @@ int KDEsuClient::connect()
     gid_t egid;
     // Security: if socket exists, we must own it
     if (getpeereid(d->sockfd, &euid, &egid) == 0 && euid != getuid()) {
-        qWarning() << "socket not owned by me! socket uid =" << euid;
+        qCWarning(KSU_LOG) << "socket not owned by me! socket uid =" << euid;
         close(d->sockfd);
         d->sockfd = -1;
         return -1;
@@ -124,17 +122,17 @@ int KDEsuClient::connect()
     // create a socket that is owned by us.
     QT_STATBUF s;
     if (QT_LSTAT(d->sock.constData(), &s) != 0) {
-        qWarning() << "stat failed (" << d->sock << ")";
+        qCWarning(KSU_LOG) << "stat failed (" << d->sock << ")";
         close(d->sockfd); d->sockfd = -1;
         return -1;
     }
     if (s.st_uid != getuid()) {
-        qWarning() << "socket not owned by me! socket uid =" << s.st_uid;
+        qCWarning(KSU_LOG) << "socket not owned by me! socket uid =" << s.st_uid;
         close(d->sockfd); d->sockfd = -1;
         return -1;
     }
     if (!S_ISSOCK(s.st_mode)) {
-        qWarning() << "socket is not a socket (" << d->sock << ")";
+        qCWarning(KSU_LOG) << "socket is not a socket (" << d->sock << ")";
         close(d->sockfd); d->sockfd = -1;
         return -1;
     }
@@ -145,7 +143,7 @@ int KDEsuClient::connect()
 
     // Security: if socket exists, we must own it
     if (getsockopt(d->sockfd, SOL_SOCKET, SO_PEERCRED, &cred, &siz) == 0 && cred.uid != getuid()) {
-        qWarning() << "socket not owned by me! socket uid =" << cred.uid;
+        qCWarning(KSU_LOG) << "socket not owned by me! socket uid =" << cred.uid;
         close(d->sockfd); d->sockfd = -1;
         return -1;
     }
@@ -189,7 +187,7 @@ int KDEsuClient::command(const QByteArray &cmd, QByteArray *result)
     char buf[1024];
     int nbytes = recv(d->sockfd, buf, 1023, 0);
     if (nbytes <= 0) {
-        qWarning() << "[" << __FILE__ << ":" << __LINE__ << "] " << "no reply from daemon.";
+        qCWarning(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] " << "no reply from daemon.";
         return -1;
     }
     buf[nbytes] = '\000';
@@ -382,7 +380,7 @@ static QString findDaemon()
     if (!QFile::exists(daemon)) { // if not in libexec, find it in PATH
         daemon = QStandardPaths::findExecutable(QStringLiteral("kdesud"));
         if (daemon.isEmpty()) {
-            qWarning() << "kdesud daemon not found.";
+            qCWarning(KSU_LOG) << "kdesud daemon not found.";
         }
     }
     return daemon;
@@ -399,7 +397,7 @@ bool KDEsuClient::isServerSGID()
 
     QT_STATBUF sbuf;
     if (QT_STAT(QFile::encodeName(d->daemon).constData(), &sbuf) < 0) {
-        qWarning() << "[" << __FILE__ << ":" << __LINE__ << "] " << "stat():" << strerror(errno);
+        qCWarning(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] " << "stat():" << strerror(errno);
         return false;
     }
     return (sbuf.st_mode & S_ISGID);
@@ -415,7 +413,7 @@ int KDEsuClient::startServer()
     }
 
     if (!isServerSGID()) {
-        qWarning() << "[" << __FILE__ << ":" << __LINE__ << "] " << "kdesud not setgid!";
+        qCWarning(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] " << "kdesud not setgid!";
     }
 
     // kdesud only forks to the background after it is accepting
